@@ -6,8 +6,6 @@
 # For further information on the license, see the LICENSE.txt file.           #
 ###############################################################################
 """Check versions"""
-from __future__ import print_function
-from __future__ import absolute_import
 
 import sys
 import json
